@@ -13,7 +13,7 @@ class Formatter:
 	def __init__(self):
 		pass
 	
-	def delta_to_string(self,delta, as_dict=False):
+	def get_delta(self,delta, as_dict=False):
 		"""
 		Convert a timedelta object to string.
 		
@@ -94,7 +94,7 @@ class Formatter:
 		else:
 			return dur
 	
-	def datetime_to_string(self,now, past, as_dict=False):
+	def past_to_now(self,past, now, as_dict=False):
 		"""Past date difference compared to current time
 		
 		Parameters 
@@ -213,8 +213,126 @@ class Formatter:
 		if datetime1 < datetime2:
 			datetime1, datetime2 = datetime2, datetime1
 		
-		data = self.datetime_to_string(datetime1, datetime2, as_dict)
+		data = self.past_to_now(datetime1, datetime2, as_dict)
 		return data
+	
+	def natural_date(self, date, as_dict=False):
+		"""
+		datetime object to a human readable time
+		
+		Parameters
+		- date				a datetime.date object
+		- as_dict			Whether it should return a dictionary or a string. Default False
+		
+		return				string or dictionary according to as_dick kwarg
+		"""
+		if not isinstance(date, dt.date):
+			raise NotValidObject("date must be a object of 'datetime.date'")
+		
+		date = dt.datetime.strftime(date, "%d")
+		
+		day_short = dt.datetime.strftime(date, "%a")
+		day_full = dt.datetime.strftime(date, "%A")
+		
+		month_short = dt.datetime.strftime(date, "%b")
+		month_full = dt.datetime.strftime(date, "%B")
+		
+		year_short = dt.datetime.strftime(date, "%y")
+		year_full = dt.datetime.strftime(date, "%Y")
+		
+		if as_dict:
+			return {'date': date, 'day_short': day_short, 'day_full': day_full, 'year_short': year_short, 'year_full': year_full, 'month_short': month_short, 'month_full': month_full, 'date': date}
+		
+		
+		date_part = dt.datetime.strftime(date, "%A, %d %b %Y")
+		
+		return date_part
+	
+	def natural_time(self, time, as_dict=False, format=12):
+		"""
+		datetime object to a human readable time
+		
+		Parameters
+		- time				a datetime.time object
+		- as_dict			Whether it should return a dictionary or a string. Default False
+		
+		return				string or dictionary according to as_dick kwarg
+		"""
+		valids = [12, 24]
+		
+		if format not in valids:
+			raise ValueError("for must be either 12 or 24")
+		
+		if not isinstance(time, dt.time):
+			raise NotValidObject("time must be a object of 'datetime.time'")
+		
+		hour = time.hour
+		minute = time.minute
+		locale = None
+		
+		if format == 12:
+			if hour >12:
+				hour = hour-12
+				locale = "PM"
+			else:
+				hour = hour
+				locale = "AM"
+				
+			data = f"{hour}:{minute} {locale}"
+			
+		if format == 24:
+			data = f"{hour}:{minute}"
+		
+		if as_dict and format == 12:
+			return {'hour':hour, 'minute': minute, 'locale':locale}
+		
+		if as_dict and format == 24:
+			return {'hour':hour, 'minute': minute}
+		
+		return data
+		
+	def natural_datetime(self, date_time, as_dict=False):
+		"""
+		datetime object to a human readable time
+		
+		Parameters
+		- date_time		a datetime.datetime object
+		- as_dict			Whether it should return a dictionary or a string. Default False
+		
+		return				string or dictionary according to as_dick kwarg
+		"""
+		if isinstance(date_time, dt.date):
+			return self.natural_date(date_time, as_dict)
+		
+		if isinstance(date_time, dt.time):
+			return self.natural_time(date_time, as_dict)
+		
+		date = dt.datetime.strftime(date_time, "%d")
+		
+		day_short = dt.datetime.strftime(date_time, "%a")
+		day_full = dt.datetime.strftime(date_time, "%A")
+		
+		month_short = dt.datetime.strftime(date_time, "%b")
+		month_full = dt.datetime.strftime(date_time, "%B")
+		
+		year_short = dt.datetime.strftime(date_time, "%y")
+		year_full = dt.datetime.strftime(date_time, "%Y")
+
+		hour = dt.datetime.strftime(date_time, "%I")
+		minute = dt.datetime.strftime(date_time, "%m")
+		locale = dt.datetime.strftime(date_time, "%p")
+		
+		if as_dict:
+			return {'date': date, 'day_short': day_short, 'day_full': day_full, 'year_short': year_short, 'year_full': year_full, 'month_short': month_short, 'month_full': month_full, 'date': date, 'hour':hour, 'minute': minute, 'locale': locale}
+		
+		date_part = dt.datetime.strftime(date_time, "%A, %d %b %Y")
+		time_part = dt.datetime.strftime(date_time, "%I:%M %p")
+		
+		return date_part + " at " + time_part
+		
+		
+
+
 		
 		
 		
\ No newline at end of file
